# Generated by Django 3.2.12 on 2022-03-21 22:28

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('sites', '0002_alter_domain_unique'),
        ('simpel_pages', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='page',
            name='sites',
            field=models.ManyToManyField(related_name='simpelpages', to='sites.Site', verbose_name='sites'),
        ),
    ]
